/**
 * @typedef YosysRawNet
 * @property {string} creator - JSON 的创建者信息，通常是 Yosys 的版本和构建详情。
 * @property {Record<string, YosysNetModule>} modules - 模块名称到模块定义的映射。
 * @property {Record<string, YosysModel>} [models] - 模型定义的映射（仅在使用 `-aig` 选项时存在）。
 */

/**
 * @typedef YosysNetModule
 * @property {ModuleAttribute} attributes - 模块的属性，如是否为顶层模块及其源文件。
 * @property {Record<string, string>} [parameter_default_values] - 参数的默认值。
 * @property {Record<string, YosysPort>} ports - 端口名称到端口定义的映射。
 * @property {Record<string, YosysCell>} cells - 单元名称到单元定义的映射。
 * @property {Record<string, YosysMemory>} [memories] - 内存名称到内存定义的映射。
 * @property {Record<string, YosysNetname>} netnames - 网络名称到网络定义的映射。
 */

/**
 * @typedef ModuleAttribute
 * @property {string} top - 表示该模块是否为顶层模块（1 表示是，0 表示否）。
 * @property {string} src - 模块定义的源文件和行号。
 * @property {string} [dynports] - 动态端口标志（1 表示是，0 表示否）。
 * @property {string} [hdlname] - HDL 名称。
 */

/**
 * @typedef YosysPort
 * @property {string} direction - 端口的方向（例如 "input"、"output" 或 "inout"）。
 * @property {number[]} bits - 与端口关联的位索引。
 * @property {number} [offset] - 使用的最低位索引（如果非 0）。
 * @property {number} [upto] - 如果端口位索引是 MSB-first，则为 1。
 * @property {number} [signed] - 如果端口是有符号的，则为 1。
 */

/**
 * @typedef YosysCell
 * @property {number} hide_name - 是否隐藏单元名称（1 表示是，0 表示否）。
 * @property {string} type - 单元的类型（例如 "$_AND_" 或 "$_XOR_"）。
 * @property {string} [model] - AIG 模型名称（仅在使用 `-aig` 选项时存在）。
 * @property {Record<string, any>} [parameters] - 与单元关联的参数（如果有）。
 * @property {CellAttribute} attributes - 单元的属性，如源文件和行号。
 * @property {Record<string, string>} port_directions - 端口名称到端口方向的映射（例如 "input"、"output" 或 "inout"）。
 * @property {Record<string, number[]>} connections - 端口名称到连接位索引的映射。
 */

/**
 * @typedef CellAttribute
 * @property {string} src - 单元定义的源文件和行号。
 */

/**
 * @typedef YosysMemory
 * @property {number} hide_name - 是否隐藏内存名称（1 表示是，0 表示否）。
 * @property {Record<string, any>} attributes - 内存的属性。
 * @property {number} width - 内存的宽度。
 * @property {number} start_offset - 最低有效内存地址。
 * @property {number} size - 内存的大小。
 */

/**
 * @typedef YosysNetname
 * @property {number} hide_name - 是否隐藏网络名称（1 表示是，0 表示否）。
 * @property {number[]} bits - 与网络名称关联的位索引。
 * @property {number} [offset] - 使用的最低位索引（如果非 0）。
 * @property {number} [upto] - 如果端口位索引是 MSB-first，则为 1。
 * @property {number} [signed] - 如果端口是有符号的，则为 1。
 */

/**
 * @typedef YosysModel
 * @property {Array<Array<any>>} [model_name] - AIG 模型的节点列表。
 */

/**
 * @typedef YosysAIGNode
 * @property {string} type - 节点类型（例如 "port"、"nport"、"and"、"nand"、"true"、"false"）。
 * @property {string} [portname] - 端口名称（如果节点类型为 "port" 或 "nport"）。
 * @property {number} [bitindex] - 位索引（如果节点类型为 "port" 或 "nport"）。
 * @property {number} [node_index] - 节点索引（如果节点类型为 "and" 或 "nand"）。
 * @property {Array<string>} [out_list] - 输出端口名称和位索引的列表。
 */